@@ -1,34 +1,22 @@
 package Log::ger::Level::FromEnv;
 
-our $DATE = '2018-02-05'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-10'; # DATE
+our $DIST = 'Log-ger-Level-FromEnv'; # DIST
+our $VERSION = '0.004'; # VERSION
 
-use Log::ger ();
+use Log::ger::Util;
 
-if (my $ll = $ENV{LOG_LEVEL}) {
-    if ($ll eq 'off' || $ll == 0) {
-        $Log::ger::Current_Level = 0;
-    } elsif ($ll eq 'fatal' || $ll == 10) {
-        $Log::ger::Current_Level = 10;
-    } elsif ($ll eq 'error' || $ll == 20) {
-        $Log::ger::Current_Level = 20;
-    } elsif ($ll eq 'warn' || $ll eq 'warning' || $ll == 30) {
-        $Log::ger::Current_Level = 30;
-    } elsif ($ll eq 'info' || $ll == 40) {
-        $Log::ger::Current_Level = 40;
-    } elsif ($ll eq 'debug' || $ll == 50) {
-        $Log::ger::Current_Level = 50;
-    } elsif ($ll eq 'trace' || $ll == 60) {
-        $Log::ger::Current_Level = 60;
-    }
+if (defined($ll = $ENV{LOG_LEVEL})) {
+    Log::ger::Util::set_level($ll);
 } elsif ($ENV{TRACE}) {
-    $Log::ger::Current_Level = 60;
+    Log::ger::Util::set_level("trace");
 } elsif ($ENV{DEBUG}) {
-    $Log::ger::Current_Level = 50;
+    Log::ger::Util::set_level("debug");
 } elsif ($ENV{VERBOSE}) {
-    $Log::ger::Current_Level = 40;
+    Log::ger::Util::set_level("info");
 } elsif ($ENV{QUIET}) {
-    $Log::ger::Current_Level = 20;
+    Log::ger::Util::set_level("error");
 }
 
 1;
@@ -46,7 +34,7 @@ Log::ger::Level::FromEnv - Set default log level from some environment variables
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -64,17 +52,21 @@ log level to trace (60)), C<DEBUG> (if true, will set log level to debug (50)),
 C<VERBOSE> (if true, will set log level to info (40)), C<QUIET> (if true, will
 set log level to error (20)).
 
-This is convenient for CLI programs.
+This is convenient for CLI programs or one-liners.
 
 =head1 SEE ALSO
 
+L<Log::ger::App>
+
+L<Log::ger::Screen>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
